Structs
- Create
Ghost Commit Options - Options to control ghost commit creation.
- Ghost
Commit - Details of a ghost commit created from a repository state.
Enums
- GitTooling
Error - Errors returned while managing git worktree snapshots.
Functions
- create_
ghost_ commit - Create a ghost commit capturing the current state of the repository’s working tree.
- create_
symlink - restore_
ghost_ commit - Restore the working tree to match the provided ghost commit.
- restore_
to_ commit - Restore the working tree to match the given commit ID.